@@ -161,13 +161,19 @@
 #'   Deboeck, P. R., & Preacher, K. J. (2015).
 #'   No need to be discrete:
 #'   A method for continuous time mediation analysis.
-#'   Structural Equation Modeling: A Multidisciplinary Journal, 23 (1), 61–75.
+#'   Structural Equation Modeling: A Multidisciplinary Journal, 23 (1), 61-75.
 #'   \doi{10.1080/10705511.2014.973960}
 #'
+#'   Pesigan, I. J. A., Russell, M. A., & Chow, S.-M. (2025).
+#'   Inferences and effect sizes for direct, indirect, and total effects
+#'   in continuous-time mediation models.
+#'   Psychological Methods.
+#'   \doi{10.1037/met0000779}
+#'
 #'   Ryan, O., & Hamaker, E. L. (2021).
 #'   Time to intervene:
 #'   A continuous-time approach to network analysis and centrality.
-#'   Psychometrika, 87 (1), 214–252.
+#'   Psychometrika, 87 (1), 214-252.
 #'   \doi{10.1007/s11336-021-09767-0}
 #'
 #' @author Ivan Jacob Agaloos Pesigan
@@ -247,7 +253,7 @@ Indirect <- function(phi,
     from %in% idx,
     to %in% idx
   )
-  for (i in seq_len(length(med))) {
+  for (i in seq_along(med)) {
     stopifnot(
       med[i] %in% idx
     )
